@@ -129,6 +129,12 @@ This attribute sets user/uid for spawned process
 
 This class implements the following methods
 
+=head2 again
+
+This method is called immediately after creating the instance and returns it
+
+B<NOTE:> Internal use only for subclasses!
+
 =head2 daemonize
 
     $g = $g->daemonize;
@@ -160,6 +166,15 @@ This method returns status of daemon:
     True - the process is an daemon;
     False - the process is not daemon;
 
+=head2 is_spirited
+
+    my $is_spirited = $g->is_spirited;
+
+This method returns status of spirit:
+
+    True - the process is an spirit;
+    False - the process is not spirit;
+
 =head2 log
 
     my $log = $g->log;
@@ -589,7 +604,7 @@ Serż Minus (Sergey Lepenkov) L<https://www.serzik.com> E<lt>abalama@cpan.orgE<g
 
 =head1 COPYRIGHT
 
-Copyright (C) 1998-2023 D&D Corporation. All Rights Reserved
+Copyright (C) 1998-2024 D&D Corporation. All Rights Reserved
 
 =head1 LICENSE
 
@@ -600,7 +615,7 @@ See C<LICENSE> file and L<https://dev.perl.org/licenses/>
 
 =cut
 
-our $VERSION = '1.00';
+our $VERSION = '1.01';
 
 use Carp qw/carp croak/;
 use Cwd qw/getcwd/;
@@ -679,6 +694,7 @@ sub new {
         ppid        => 0,   # PID before daemonize
         pid         => 0,   # PID daemonized process
         daemonized  => 0,   # 0 - no daemonized; 1 - daemonized
+        spirited    => 0,   # 0 - is not spirit; 1 - is spirit (See ::Prefork)
 
         # Manage
         ok          => 0,   # 1 - Ok. Process is healthy (ok)
@@ -686,8 +702,9 @@ sub new {
         interrupt   => 0,   # The interrupt counter
 
     }, $class;
-    return $self;
+    return $self->again(%$args);
 }
+sub again { shift }
 sub log {
     my $self = shift;
     return $self->{_log} //= Acme::Ghost::Log->new(
@@ -815,6 +832,7 @@ sub daemonize {
 
     # Set a signal handler to make sure SIGINT's remove our pid_file
     $SIG{TERM} = $SIG{INT} = sub {
+        POSIX::_exit(1) if $self->is_spirited;
         $self->cleanup(1);
         $log->fatal("Termination on INT/TERM signal");
         $self->filepid->remove;
@@ -827,6 +845,7 @@ sub daemonize {
     return $self;
 }
 sub is_daemonized { shift->{daemonized} }
+sub is_spirited { shift->{spirited} }
 sub pid { shift->{pid} }
 
 # Hooks
@@ -846,7 +865,7 @@ sub flush { # Flush process counters
 }
 sub ok {
     my $self = shift;
-    return 0 unless defined $self->{ppid}; # No parent pid found (it is not daemon?)
+    return 0 unless defined $self->{ppid}; # No parent pid found (it is not a daemon?)
     return $self->{ok} ? 1 : 0;
 }
 
@@ -861,6 +880,7 @@ sub _term {
     $self->{signo} = $signo;
     $self->log->debug(sprintf("Request for terminate of ghost process %s received on signal %s", $self->pid, $signo));
     if ($self->{interrupt} >= INT_TRIES) { # Forced terminate
+        POSIX::_exit(1) if $self->is_spirited;
         $self->cleanup(1);
         $self->log->fatal(sprintf("Ghost process %s forcefully terminated on signal %s", $self->pid, $signo));
         $self->filepid->remove;
@@ -890,9 +910,9 @@ sub stop {
        $self->{pid} = $pid;
     return 0 unless $pid; # Not running
 
-    # Try SIGTERM ... 6s ... SIGINT ... 3s ... SIGKILL ... 3s ... UNDEAD!
+    # Try SIGQUIT ... 2s ... SIGTERM ... 4s ... SIGINT ... 3s ... SIGKILL ... 3s ... UNDEAD!
     my $tsig = 0;
-    for ([SIGTERM, 2], [SIGTERM, 2], [SIGTERM, 2], [SIGINT, 3], [SIGKILL, 3]) {
+    for ([SIGQUIT, 2], [SIGTERM, 2], [SIGTERM, 2], [SIGINT, 3], [SIGKILL, 3]) {
         my ($signo, $timeout) = @$_;
         kill $signo, $pid;
         for (1 .. $timeout) { # abort early if the process is now stopped
@@ -981,6 +1001,7 @@ sub DESTROY {
     my $self = shift;
     return unless $self;
     return unless $self->{daemonized};
+    return if $self->{spirited}; # Skip cleanup if it is spirit
     $self->cleanup(0);
     $self->filepid->remove;
 }
